@@ -1,8 +1,10 @@
 from xml.dom.minidom import Document, parseString
-import httplib
+
+from six.moves import http_client
 import re
 import logging
 import datetime
+from django.utils.encoding import python_2_unicode_compatible
 
 from oscar.apps.payment.exceptions import GatewayError
 
@@ -23,6 +25,7 @@ TXN_REFUND = 'txn_refund'
 ACCEPTED, DECLINED, INVALID_CREDENTIALS = '1', '7', '10'
 
 
+@python_2_unicode_compatible
 class Response(object):
     """
     Encapsulate a Datacash response
@@ -59,9 +62,6 @@ class Response(object):
         return key in self.data
 
     def __str__(self):
-        return self.__unicode__()
-
-    def __unicode__(self):
         return self.response_xml
 
     @property
@@ -99,13 +99,13 @@ class Gateway(object):
 
     def _fetch_response_xml(self, request_xml):
         # Need to fill in HTTP request here
-        conn = httplib.HTTPSConnection(self._host, 443, timeout=30)
+        conn = http_client.HTTPSConnection(self._host, 443, timeout=30)
         headers = {"Content-type": "application/xml",
                    "Accept": ""}
         conn.request("POST", self._path, request_xml.encode('utf8'), headers)
         response = conn.getresponse()
         response_xml = response.read()
-        if response.status != httplib.OK:
+        if response.status != http_client.OK:
             raise GatewayError("Unable to communicate with payment gateway (code: %s, response: %s)" % (response.status, response_xml))
         conn.close()
         return response_xml
