@@ -1,8 +1,3 @@
-from django.db.models import get_model
-
-Order = get_model('order', 'Order')
-
-
 def build_data_dict(request=None, user=None, email=None, order_number=None,
                     basket=None, shipping_address=None, billing_address=None):
     """
@@ -89,10 +84,9 @@ def build_order_info(basket):
     payload = {'products': []}
     for line in basket.all_lines():
         product = line.product
-        stockrecord = product.stockrecord
         datum = {
             'code': product.upc,
-            'price': stockrecord.price_incl_tax,
+            'price': line.price_incl_tax,
             'prod_description': product.description,
             'prod_id': product.id,
             'quantity': line.quantity,
