@@ -22,15 +22,16 @@ class CallbackView(generic.View):
         try:
             # Datacash send both XML and query string with the same content
             # type header :( so we have to check for XML syntax.
-            if '<?xml' in request.body:
+            if b'<?xml' in request.body:
                 response = models.FraudResponse.create_from_xml(request.body)
             else:
-                response = models.FraudResponse.create_from_querystring(request.body)
-        except Exception, e:
-            logger.error("Error raised handling response:\n%s", request.body)
-            logger.exception(e)
+                response = models.FraudResponse.create_from_querystring(
+                    request.body)
+        except Exception:
+            logger.error("Error raised handling response:\n%s", request.body,
+                         exc_info=True)
             return http.HttpResponseServerError("error")
         else:
             logger.info("Successful response received with merchant ref %s",
                         response.merchant_order_ref)
-            return http.HttpResponse("ok")
+            return http.HttpResponse(b"ok")
